pub struct Sindy {
pub names: Vec<String>,
pub coeffs: DMatrix<f64>,
}Expand description
A discovered model: the library term names and the sparse coefficient matrix Ξ (one column per state
dimension).
Fields
names: Vec<String>coeffs: DMatrix<f64>coeffs[(term, dim)] — coefficient of library term in the equation for state component dim.
Implementations